@@ -27,7 +27,13 @@ class DatabaseCreation(BaseDatabaseCreation):
         #   so we can proceed if we're keeping the DB anyway.
         # https://github.com/microsoft/mssql-django/issues/61
         try:
-            return super()._create_test_db(verbosity, autoclobber, keepdb)
+            test_database_name = super()._create_test_db(verbosity, autoclobber, keepdb)
+            
+            # Create required schemas for Django tests (only for 5.2+)
+            if django_version >= (5, 2):
+                self._create_test_schemas(test_database_name, verbosity)
+
+            return test_database_name
         except InterfaceError as err:
             if err.args[0] == '28000' and keepdb:
                 self.log('Received error %s, proceeding because keepdb=True' % (
@@ -36,6 +42,32 @@ class DatabaseCreation(BaseDatabaseCreation):
             else:
                 raise err
 
+    def _create_test_schemas(self, test_database_name, verbosity):
+        """
+        Create required schemas in test database for Django tests.
+        """
+        schemas_to_create = ['inspectdb_special', 'inspectdb_pascal']
+        
+        # Use a cursor connected to the test database
+        test_settings = self.connection.settings_dict.copy()
+        test_settings['NAME'] = test_database_name
+        test_connection = self.connection.__class__(test_settings)
+        
+        try:
+            with test_connection.cursor() as cursor:
+                for schema in schemas_to_create:
+                    try:
+                        quoted_schema = self.connection.ops.quote_name(schema)
+                        cursor.execute(f"CREATE SCHEMA {quoted_schema}")
+                        if verbosity >= 2:
+                            self.log(f'Created schema {schema} in test database {test_database_name}')
+                    except Exception as e:
+                        # Schema might already exist, which is fine
+                        if verbosity >= 2:
+                            self.log(f'Schema {schema} creation failed (might already exist): {e}')
+        finally:
+            test_connection.close()
+
     def _destroy_test_db(self, test_database_name, verbosity):
         """
         Internal implementation - remove the test db tables.
