@@ -21,6 +21,7 @@ from django.db.backends.ddl_references import (
 from django import VERSION as django_version
 from django.db.models import NOT_PROVIDED, Index, UniqueConstraint
 from django.db.models.fields import AutoField, BigAutoField
+from django.db.models.fields.related import ForeignKey
 from django.db.models.sql.where import AND
 from django.db.transaction import TransactionManagementError
 from django.utils.encoding import force_str
@@ -183,7 +184,7 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
         argument) a default to new_field's column.
         """
         column = self.quote_name(new_field.column)
-        
+
         if drop:
             # SQL Server requires the name of the default constraint
             result = self.execute(
@@ -291,17 +292,24 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
     def _model_indexes_sql(self, model):
         """
         Return a list of all index SQL statements (field indexes,
-        index_together, Meta.indexes) for the specified model.
+        Meta.indexes) for the specified model.
         """
         if not model._meta.managed or model._meta.proxy or model._meta.swapped:
             return []
         output = []
         for field in model._meta.local_fields:
             output.extend(self._field_indexes_sql(model, field))
-
-        for field_names in model._meta.index_together:
-            fields = [model._meta.get_field(field) for field in field_names]
-            output.append(self._create_index_sql(model, fields, suffix="_idx"))
+         # meta.index_together is removed in Django 5.1, so add a version check to handle compatibility
+        if django_version < (5, 1):
+            # Iterate over each set of field names defined in index_together
+            for field_names in model._meta.index_together:
+               # Get the actual field objects for each field name
+               fields = [model._meta.get_field(field) for field in field_names]
+               # Generate the SQL statement to create the index for these fields
+               sql=self._create_index_sql(model, fields, suffix="_idx")
+               # If SQL was generated (not None), add it to the output list
+               if sql:
+                 output.append(sql)
 
         if django_version >= (4, 0):
             for field_names in model._meta.unique_together:
@@ -426,10 +434,20 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
             )
         ):
             # Drop index, SQL Server requires explicit deletion
-            if not hasattr(new_field, 'db_constraint') or not new_field.db_constraint:
-                index_names = self._constraint_names(model, [old_field.column], index=True)
-                for index_name in index_names:
-                    self.execute(self._delete_constraint_sql(self.sql_delete_index, model, index_name))
+            if (
+                not hasattr(new_field, "db_constraint")
+                or not new_field.db_constraint
+            ):
+                if(django_version < (4, 2) 
+                   or (
+                       not isinstance(new_field, ForeignKey)
+                       or type(new_field.db_comment) == type(None)
+                       or "fk_on_delete_keep_index" not in new_field.db_comment
+                       )
+                   ):
+                    index_names = self._constraint_names(model, [old_field.column], index=True)
+                    for index_name in index_names:
+                        self.execute(self._delete_constraint_sql(self.sql_delete_index, model, index_name))
 
             fk_names = self._constraint_names(model, [old_field.column], foreign_key=True)
             if strict and len(fk_names) != 1:
@@ -792,10 +810,15 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
             if old_field.db_index and new_field.db_index:
                 index_columns.append([old_field])
             else:
-                for fields in model._meta.index_together:
-                    columns = [model._meta.get_field(field) for field in fields]
-                    if old_field.column in [c.column for c in columns]:
-                        index_columns.append(columns)
+                # Handle index_together for only django version < 5.1
+                if django_version < (5, 1):
+                   # Get the field objects for each field name in the index_together. 
+                   for fields in model._meta.index_together:
+                      # If the old field's column is among the columns for this index,
+                      # add this set of columns to index_columns for later index recreation.
+                      columns = [model._meta.get_field(field) for field in fields]
+                      if old_field.column in [c.column for c in columns]:
+                         index_columns.append(columns)
             if index_columns:
                 for columns in index_columns:
                     create_index_sql_statement = self._create_index_sql(model, columns)
@@ -911,16 +934,28 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
             self.connection.close()
 
     def _delete_indexes(self, model, old_field, new_field):
+        if (
+            django_version >= (4, 2)
+            and isinstance(new_field, ForeignKey)
+            and type(new_field.db_comment) != type(None)
+            and "fk_on_delete_keep_index" in new_field.db_comment
+        ):
+            return
         index_columns = []
         index_names = []
         if old_field.db_index and new_field.db_index:
             index_columns.append([old_field.column])
         elif old_field.null != new_field.null:
             index_columns.append([old_field.column])
-        for fields in model._meta.index_together:
-            columns = [model._meta.get_field(field).column for field in fields]
-            if old_field.column in columns:
-                index_columns.append(columns)
+        # Handle index_together for only django version < 5.1    
+        if django_version < (5, 1):  
+           # Iterate over each set of field names defined in index_together  
+           for fields in model._meta.index_together:
+              # Get the actual column names for each field in the set
+              columns = [model._meta.get_field(field).column for field in fields]
+              # If the old field's column is among these columns, add to index_columns for later index deletion
+              if old_field.column in columns:
+                 index_columns.append(columns)
 
         for index in model._meta.indexes:
             columns = [model._meta.get_field(field).column for field in index.fields]
